@@ -18,6 +18,7 @@ import csv
 
 jinja_env = utils.get_jinja_env()
 
+
 def get_wiki(dictionary, collection_name):
     wiki_key = dictionary["wiki_key"]
 
@@ -39,7 +40,9 @@ def get_wiki_from_request(request, collection_name):
 def get_system_information(request, fmt):
     if fmt == "json":
         information = {}
-        if settings.TORQUE_COLLECTIONS_ALIAS and settings.TORQUE_DOCUMENTS_ALIAS:
+        if getattr(settings, "TORQUE_COLLECTIONS_ALIAS", False) and getattr(
+            settings, "TORQUE_DOCUMENTS_ALIAS", False
+        ):
             information["collections_alias"] = settings.TORQUE_COLLECTIONS_ALIAS
             information["documents_alias"] = settings.TORQUE_DOCUMENTS_ALIAS
 
@@ -765,9 +768,8 @@ def get_csv(request, name, fmt):
                 ).prefetch_related("field")
             }
             for field_name in valid_field_names:
-                if (
-                    field_name in values_by_field
-                    and field_name in getattr(settings, "TORQUE_CSV_PROCESSORS", {})
+                if field_name in values_by_field and field_name in getattr(
+                    settings, "TORQUE_CSV_PROCESSORS", {}
                 ):
                     row.extend(
                         settings.TORQUE_CSV_PROCESSORS[field_name].process_value(
